//=========================================================================
//
// class FileAudioProvider
//
// Author:			Grzegorz Lewandowski
// Created:			09/23/97
//
//-------------------------------------------------------------------------

import java.io.*;

class FileAudioProvider extends AudioProvider
{
	FileInputStream inputStream;

	FileAudioProvider( AudioDecoder dec, AudioIOStream str ,String fileName )
	{
		super( dec, str );
		
		try
		{
			inputStream = new FileInputStream( fileName );
		}
		catch( FileNotFoundException e )
		{
			System.err.println( "File '" + e.getMessage() + "' not found" );
			System.exit( -1 );
		}
		catch( SecurityException e )
		{
			System.err.println( "FileAudioProvider: Caught SecurityException: " + e.getMessage() );
			System.exit( -1 );
		}

		// this should be in ADPCMdecoder
		// will be moved there later
		byte[] Header;
		Header = new byte[ 26 ];
		try
		{
			int nRate;
			byte nChannels, nBits;
			inputStream.read( Header );
			nRate = Header[ 12 ] * 256 + Header[ 13 ];
			nChannels = Header[ 14 ];
			nBits = Header[ 15 ];
			System.out.println( "Rate: " + nRate );
			System.out.println( "Channels: " + nChannels );
			System.out.println( "Bits per sample: " + nBits );
		}
		catch( IOException e )
		{
			System.err.println( "FileAudioProvider: Caught IOException: " + e.getMessage() );
			System.exit( -1 );
		}
	}

	public void close()
	{
		try
		{
			inputStream.close();
		}
		catch( IOException e )
		{
			System.err.println( "FileAudioProvider: IOException " + e );
		}
	}

	protected boolean putAudio()
	{
		int nResult;
		boolean bReturn;

		try
		{
			nResult = inputStream.read( inBuffer );
			if( nResult != -1 )
			{
				bReturn = true;
				// System.out.println( "FileAudioProvider: " + nResult + " bytes read" );
			}
			else
			{
				bReturn = false;
				System.out.println( "FileAudioProvider: EOF" );
			}
		}
		catch( IOException e )
		{
			System.err.println( "FileAudioProvider: Caught IOException: " + e.getMessage() );
			bReturn = false;
		}
		return bReturn;
	}
}